@@ -170,10 +170,10 @@ class TestOLT(unittest.TestCase):
         pon = pon_port.pons.add()
         pon.id = '100001'
         self._await(olt.load())
-        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'TestAP', 'topology2': 'MySite', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='TestAP', attributes={'topology1': 'TestAP', 'topology2': 'MySite', 'topology1_snmp': 'TestAP', 'system': 'net'})
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 1)
-        self.assertEqual(ap_refs.get('TestAP.100001'), exp_ref)
+        self.assertEqual(ap_refs.get('TestAP'), exp_ref)
 
     def test_olt_legacy_mode_list(self):
         """Network metadata is created for site/ap if this OLT is configured for legacy mode."""
@@ -184,10 +184,10 @@ class TestOLT(unittest.TestCase):
         pon = pon_port.pons.add()
         pon.id = '100001'
         self._await(olt.load())
-        exp_ref = NetworkMetadataReference(type='ap', value='TestAP.100001', attributes={'topology1': 'TestAP', 'topology2': 'MySite', 'ap_config': 'TestAP.100001', 'topology1_snmp': 'TestAP', 'system': 'net'})
+        exp_ref = NetworkMetadataReference(type='ap', value='TestAP', attributes={'topology1': 'TestAP', 'topology2': 'MySite', 'topology1_snmp': 'TestAP', 'system': 'net'})
         ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
         self.assertEqual(len(ap_refs), 1)
-        self.assertEqual(ap_refs.get('TestAP.100001'), exp_ref)
+        self.assertEqual(ap_refs.get('TestAP'), exp_ref)
 
     def test_olt_legacy_mode_list_other(self):
         """Network metadata is created for site/ap if this OLT is configured for legacy mode."""
@@ -521,3 +521,64 @@ class TestOLT(unittest.TestCase):
             '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
             '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2.200001', 'sm': '00:00:02:00:00:03'}),
         })
+
+    def test_ont_legacy_mode_enabled(self):
+        """Test ONT mapping in legacy mode."""
+        self.ctx.olt_legacy_mapping = True
+        olt = self.setup_simple_network(bridged_macs=True)
+        self.run_poll()
+
+        ap_refs = self.ctx.netmeta_model.refs.get('ap') or {}
+        # In legacy mode we create a "fake" AP ref for each OLT.
+        self.assertEqual(len(ap_refs), 4)
+        exp_ref = NetworkMetadataReference(type='ap', value='olt1', attributes={'topology1': 'Fixed OLT', 'topology2': 'MySite', 'topology1_snmp': 'olt1', 'system': 'net'})
+        self.assertEqual(ap_refs.get('olt1'), exp_ref)
+        exp_ref = NetworkMetadataReference(type='ap', value='olt2', attributes={'topology1': 'Modular OLT', 'topology2': 'MySite2', 'topology1_snmp': 'olt2', 'system': 'net'})
+        self.assertEqual(ap_refs.get('olt2'), exp_ref)
+        exp_ref = NetworkMetadataReference(type='ap', value='olt3', attributes={'topology1': 'Element with no PON', 'topology2': 'MySite', 'topology1_snmp': 'olt3', 'system': 'net'})
+        self.assertEqual(ap_refs.get('olt3'), exp_ref)
+        exp_ref = NetworkMetadataReference(type='ap', value='olt4', attributes={'topology1': 'OLT with no ONTs', 'topology2': 'MySite', 'topology1_snmp': 'olt4', 'system': 'net'})
+        self.assertEqual(ap_refs.get('olt4'), exp_ref)
+
+        # check bridged macs
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 7)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
+            '00:01:00:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+            '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+        })
+
+        # remove a bridged mac
+        del olt.module.next_neu.data.interfaces[0].links[0].bridged_mac_addresses[0]
+        self._await(olt.load())
+
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 6)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:01': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:01', attributes={'ap': 'olt1', 'sm': '00:00:02:00:00:01', 'pon': '100001'}),
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+            '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+        })
+
+        # remove a pon
+        del olt.module.next_neu.data.interfaces[0].pons[0]
+        del olt.module.next_neu.peers[0]
+        self._await(olt.load())
+
+        cpe_mac_refs = self.ctx.netmeta_model.refs.get('cpe_mac') or {}
+        self.assertEqual(len(cpe_mac_refs), 5)
+        self.assertEqual(cpe_mac_refs, {
+            '00:00:02:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:02': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:02', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:01:00:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:02', 'pon': '200001'}),
+            '00:00:02:00:00:03': NetworkMetadataReference(type='cpe_mac', value='00:00:02:00:00:03', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+            '00:01:00:00:00:04': NetworkMetadataReference(type='cpe_mac', value='00:01:00:00:00:04', attributes={'ap': 'olt2', 'sm': '00:00:02:00:00:03', 'pon': '200001'}),
+        })
